@@ -20,6 +20,26 @@ use std::sync::Mutex;
 
 // Note: 'main is a lifetime of scope of main() function
 
+fn parse_size(input: &str) -> Result<u64> {
+    if input.is_empty() {
+        anyhow::bail!("Size string must not be empty");
+    }
+
+    let i = input.len() - 1;
+    let (input, mag) = match input.as_bytes()[i] {
+        b'k' | b'K' => (&input[..i], 1 << 10),
+        b'm' | b'M' => (&input[..i], 1 << 20),
+        b'g' | b'G' => (&input[..i], 1 << 30),
+        _ => (input, 1),
+    };
+
+    let u: u64 = input
+        .parse()
+        .with_context(|| format!("could not parse {:?} as unsigned integer", input))?;
+
+    Ok(u * mag)
+}
+
 #[derive(Default)]
 pub struct Config<'main> {
     min_context: u64,
@@ -47,6 +67,8 @@ pub struct Config<'main> {
     invert_match: bool,
     one_file_system: bool,
     no_unicode: bool,
+    regex_size_limit: Option<usize>,
+    dfa_size_limit: Option<usize>,
 }
 
 impl<'main> Config<'main> {
@@ -177,24 +199,7 @@ impl<'main> Config<'main> {
     }
 
     pub fn max_filesize(&mut self, input: &str) -> Result<&mut Self> {
-        if input.is_empty() {
-            anyhow::bail!("Size string must not be empty");
-        }
-
-        let i = input.len() - 1;
-        let (input, mag) = match input.as_bytes()[i] {
-            b'k' | b'K' => (&input[..i], 1 << 10),
-            b'm' | b'M' => (&input[..i], 1 << 20),
-            b'g' | b'G' => (&input[..i], 1 << 30),
-            _ => (input, 1),
-        };
-
-        let u: u64 = input
-            .parse()
-            .context("could not parse file size value as unsigned integer")?;
-
-        self.max_filesize = Some(u * mag);
-
+        self.max_filesize = Some(parse_size(input)?);
         Ok(self)
     }
 
@@ -213,6 +218,16 @@ impl<'main> Config<'main> {
         self
     }
 
+    pub fn regex_size_limit(&mut self, input: &str) -> Result<&mut Self> {
+        self.regex_size_limit = Some(parse_size(input)? as usize);
+        Ok(self)
+    }
+
+    pub fn dfa_size_limit(&mut self, input: &str) -> Result<&mut Self> {
+        self.dfa_size_limit = Some(parse_size(input)? as usize);
+        Ok(self)
+    }
+
     fn build_walker(&self, mut paths: impl Iterator<Item = &'main OsStr>) -> Result<Walk> {
         let target = paths.next().unwrap();
 
@@ -272,6 +287,13 @@ impl<'main> Config<'main> {
                 .crlf(self.crlf);
         }
 
+        if let Some(limit) = self.regex_size_limit {
+            builder.size_limit(limit);
+        }
+        if let Some(limit) = self.dfa_size_limit {
+            builder.dfa_size_limit(limit);
+        }
+
         Ok(if self.fixed_strings {
             let mut s = regex::escape(pat);
             if self.line_regexp {
@@ -946,7 +968,7 @@ mod tests {
     }
 
     #[test]
-    fn test_parse_max_filesize() {
+    fn test_parse_size() {
         let tests = &[
             ("123", Ok(123)),
             ("123k", Ok(123 * 1024)),
@@ -956,43 +978,44 @@ mod tests {
             ("123M", Ok(123 * 1024 * 1024)),
             ("123G", Ok(123 * 1024 * 1024 * 1024)),
             ("", Err("Size string must not be empty")),
-            (
-                "abc",
-                Err("could not parse file size value as unsigned integer"),
-            ),
-            (
-                "123kk",
-                Err("could not parse file size value as unsigned integer"),
-            ),
-            (
-                "-123k",
-                Err("could not parse file size value as unsigned integer"),
-            ),
+            ("abc", Err("could not parse \"abc\" as unsigned integer")),
+            ("123kk", Err("could not parse \"123k\" as unsigned integer")),
+            ("-123k", Err("could not parse \"-123\" as unsigned integer")),
         ];
 
         for (input, want) in tests.iter().copied() {
             let mut c = Config::default();
-            let err = c.max_filesize(input).err();
-            match want {
-                Ok(want) => assert_eq!(
-                    c.max_filesize,
-                    Some(want),
-                    "wanted {} for {:?}",
-                    want,
-                    input
-                ),
-                Err(want) => {
-                    let err = err.unwrap_or_else(|| {
-                        panic!("wanted error {:?} but no error for {:?}", want, input)
-                    });
-                    let msg = format!("{}", err);
-                    assert!(
-                        msg.contains(want),
-                        "wanted error {:?} but got {:?} for {:?}",
+            let mut errs = vec![];
+            errs.push(("max-filesize", c.max_filesize(input).err()));
+            errs.push(("regex-size-limit", c.regex_size_limit(input).err()));
+            errs.push(("dfa-size-limit", c.dfa_size_limit(input).err()));
+            for (opt, err) in errs.into_iter() {
+                match want {
+                    Ok(want) => assert_eq!(
+                        c.max_filesize,
+                        Some(want),
+                        "wanted {} for {:?} ({})",
                         want,
-                        msg,
-                        input
-                    );
+                        input,
+                        opt,
+                    ),
+                    Err(want) => {
+                        let err = err.unwrap_or_else(|| {
+                            panic!(
+                                "wanted error {:?} but no error for {:?} ({})",
+                                want, input, opt
+                            )
+                        });
+                        let msg = format!("{}", err);
+                        assert!(
+                            msg.contains(want),
+                            "wanted error {:?} but got {:?} for {:?} ({})",
+                            want,
+                            msg,
+                            input,
+                            opt,
+                        );
+                    }
                 }
             }
         }
