@@ -910,8 +910,6 @@ impl<'file, W: Write> Drawer<'file, W> {
         let mut chunks = file.chunks.iter();
         let mut chunk = chunks.next().unwrap(); // OK since chunks is not empty
 
-        // Note: `bytes` contains newline at the end since SyntaxSet requires it. The newline will be trimmed when
-        // `HighlightedLine` instance is created.
         for Line(bytes, lnum) in LinesInclusive::new(&file.contents) {
             let (start, end) = *chunk;
             if lnum < start {
@@ -1083,6 +1081,10 @@ where
             Some("pac") => Some("JavaScript (Babel)"),
             _ => None,
         };
+        let name = name.or_else(|| match path.file_name().and_then(OsStr::to_str) {
+            Some(".clang-format") => Some("YAML"),
+            _ => None,
+        });
         if let Some(syntax) = name.and_then(|n| self.syntaxes.find_syntax_by_name(n)) {
             return Ok(syntax);
         }
@@ -1180,7 +1182,7 @@ mod tests {
                         l = &l[end..];
                         base += end;
                     }
-                    if ranges.len() > 0 {
+                    if !ranges.is_empty() {
                         lmats.push(LineMatch::new(lnum, ranges));
                     }
                 } else {
@@ -1253,9 +1255,11 @@ mod tests {
 
         fn run_uitest(file: File, expected_file: PathBuf, f: fn(&mut PrinterOptions<'_>) -> ()) {
             let stdout = DummyStdout(RefCell::new(vec![]));
-            let mut opts = PrinterOptions::default();
-            opts.term_width = 80;
-            opts.color_support = TermColorSupport::True;
+            let mut opts = PrinterOptions {
+                term_width: 80,
+                color_support: TermColorSupport::True,
+                ..Default::default()
+            };
             f(&mut opts);
             let mut printer = SyntectPrinter::with_assets(ASSETS.clone(), stdout, opts);
             printer.print(file).unwrap();
@@ -1396,6 +1400,7 @@ mod tests {
             test_wide_char_region_bg(|o| {
                 o.background_color = true;
             }),
+            test_wrap_accross_regions(|_| {}),
             test_wrap_match_at_second_line(|_| {}),
             test_wrap_region_accross_line(|_| {}),
             test_wrap_region_jp_accross_line(|_| {}),
@@ -1444,9 +1449,11 @@ mod tests {
             let expected = Path::new("testdata").join("syntect").join(file);
             let expected = fs::read(&expected).unwrap();
 
-            let mut opts = PrinterOptions::default();
-            opts.term_width = 80;
-            opts.color_support = TermColorSupport::True;
+            let mut opts = PrinterOptions {
+                term_width: 80,
+                color_support: TermColorSupport::True,
+                ..Default::default()
+            };
             f(&mut opts);
 
             let mut got = vec![];
@@ -1542,8 +1549,10 @@ mod tests {
 
     #[test]
     fn test_unknown_theme() {
-        let mut opts = PrinterOptions::default();
-        opts.theme = Some("this theme does not exist");
+        let opts = PrinterOptions {
+            theme: Some("this theme does not exist"),
+            ..Default::default()
+        };
         let err = match SyntectPrinter::with_stdout(opts) {
             Err(e) => e,
             Ok(_) => panic!("error did not occur"),
@@ -1589,8 +1598,10 @@ mod tests {
         let chunks = vec![(1, 1)];
         let file = File::new(PathBuf::from("test.txt"), lmats, chunks, contents.to_vec());
 
-        let mut opts = PrinterOptions::default();
-        opts.color_support = TermColorSupport::True;
+        let opts = PrinterOptions {
+            color_support: TermColorSupport::True,
+            ..Default::default()
+        };
         let stdout = DummyStdout(RefCell::new(vec![]));
         let mut printer = SyntectPrinter::with_assets(ASSETS.clone(), stdout, opts);
         printer.print(file).unwrap();
@@ -1603,8 +1614,7 @@ mod tests {
         let this_is_test_line = lines.nth(3).unwrap();
         let found = this_is_test_line
             .windows(expected.len())
-            .find(|s| s == expected)
-            .is_some();
+            .any(|s| s == expected);
         assert!(
             found,
             "line={:?}",
